===================
dj-bitcoin
===================

Django helpers for working with bitcoin


Requirements
------------

Only tested on Pyhthon 3.5 & Django 1.9 but it could work on more versions.


Quick Start
------------

Install dj-bitcoin:

.. code-block:: bash

    pip install dj-bitcoin
